# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.modelpipelinerun.v1 import modelpipelinerun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2


class ModelPipelineRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListModelPipelineRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/ListModelPipelineRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ListModelPipelineRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ListModelPipelineRunsResponse.FromString,
                )
        self.CreateModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/CreateModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.CreateModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.CreateModelPipelineRunResponse.FromString,
                )
        self.GetModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/GetModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.GetModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.GetModelPipelineRunResponse.FromString,
                )
        self.UpdateModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/UpdateModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.UpdateModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.UpdateModelPipelineRunResponse.FromString,
                )
        self.DeleteModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/DeleteModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DeleteModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DeleteModelPipelineRunResponse.FromString,
                )
        self.ApproveModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/ApproveModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ApproveModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ApproveModelPipelineRunResponse.FromString,
                )
        self.DenyModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/DenyModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DenyModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DenyModelPipelineRunResponse.FromString,
                )
        self.AbortModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/AbortModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.AbortModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.AbortModelPipelineRunResponse.FromString,
                )
        self.PauseModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/PauseModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.PauseModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.PauseModelPipelineRunResponse.FromString,
                )
        self.ResumeModelPipelineRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/ResumeModelPipelineRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ResumeModelPipelineRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ResumeModelPipelineRunResponse.FromString,
                )


class ModelPipelineRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListModelPipelineRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ApproveModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenyModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AbortModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PauseModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResumeModelPipelineRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ModelPipelineRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListModelPipelineRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModelPipelineRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ListModelPipelineRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ListModelPipelineRunsResponse.SerializeToString,
            ),
            'CreateModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.CreateModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.CreateModelPipelineRunResponse.SerializeToString,
            ),
            'GetModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.GetModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.GetModelPipelineRunResponse.SerializeToString,
            ),
            'UpdateModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.UpdateModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.UpdateModelPipelineRunResponse.SerializeToString,
            ),
            'DeleteModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DeleteModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DeleteModelPipelineRunResponse.SerializeToString,
            ),
            'ApproveModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ApproveModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ApproveModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ApproveModelPipelineRunResponse.SerializeToString,
            ),
            'DenyModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DenyModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DenyModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DenyModelPipelineRunResponse.SerializeToString,
            ),
            'AbortModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.AbortModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.AbortModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.AbortModelPipelineRunResponse.SerializeToString,
            ),
            'PauseModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.PauseModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.PauseModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.PauseModelPipelineRunResponse.SerializeToString,
            ),
            'ResumeModelPipelineRun': grpc.unary_unary_rpc_method_handler(
                    servicer.ResumeModelPipelineRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ResumeModelPipelineRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ResumeModelPipelineRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ModelPipelineRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListModelPipelineRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/ListModelPipelineRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ListModelPipelineRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ListModelPipelineRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/CreateModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.CreateModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.CreateModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/GetModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.GetModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.GetModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/UpdateModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.UpdateModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.UpdateModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/DeleteModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DeleteModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DeleteModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ApproveModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/ApproveModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ApproveModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ApproveModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenyModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/DenyModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DenyModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.DenyModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AbortModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/AbortModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.AbortModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.AbortModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PauseModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/PauseModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.PauseModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.PauseModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResumeModelPipelineRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService/ResumeModelPipelineRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ResumeModelPipelineRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_modelpipelinerun_dot_v1_dot_modelpipelinerun__pb2.ResumeModelPipelineRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/predictionstore/v1/predictionstore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOgithub.com/metaprov/modelaapi/services/predictionstore/v1/predictionstore.proto\x12\x39github.com.metaprov.modelaapi.services.predictionstore.v1\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xfa\x01\n\x18PredictionsIngestRequest\x12N\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0b\n\x03key\x18\x02 \x01(\t\x12U\n\nconnection\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12*\n\x06secret\x18\x04 \x01(\x0b\x32\x1a.k8s.io.api.core.v1.Secret\"\x1a\n\x18PredictionIngestResponse2\xcf\x01\n\x16PredictionStoreService\x12\xb4\x01\n\x06Ingest\x12S.github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest\x1aS.github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionIngestResponse\"\x00\x42;Z9github.com/metaprov/modelaapi/services/predictionstore/v1b\x06proto3')



_PREDICTIONSINGESTREQUEST = DESCRIPTOR.message_types_by_name['PredictionsIngestRequest']
_PREDICTIONINGESTRESPONSE = DESCRIPTOR.message_types_by_name['PredictionIngestResponse']
PredictionsIngestRequest = _reflection.GeneratedProtocolMessageType('PredictionsIngestRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONSINGESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictionstore.v1.predictionstore_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionsIngestRequest)
  })
_sym_db.RegisterMessage(PredictionsIngestRequest)

PredictionIngestResponse = _reflection.GeneratedProtocolMessageType('PredictionIngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREDICTIONINGESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.predictionstore.v1.predictionstore_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.predictionstore.v1.PredictionIngestResponse)
  })
_sym_db.RegisterMessage(PredictionIngestResponse)

_PREDICTIONSTORESERVICE = DESCRIPTOR.services_by_name['PredictionStoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/metaprov/modelaapi/services/predictionstore/v1'
  _PREDICTIONSINGESTREQUEST._serialized_start=320
  _PREDICTIONSINGESTREQUEST._serialized_end=570
  _PREDICTIONINGESTRESPONSE._serialized_start=572
  _PREDICTIONINGESTRESPONSE._serialized_end=598
  _PREDICTIONSTORESERVICE._serialized_start=601
  _PREDICTIONSTORESERVICE._serialized_end=808
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/cronreport/v1/cronreport.proto\x12\x34github.com.metaprov.modelaapi.services.cronreport.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xfd\x01\n\x16ListCronReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x91\x01\n\x17ListCronReportsResponse\x12]\n\x0b\x63ronreports\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReportList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18\x43reateCronReportResponse\"s\n\x17\x43reateCronReportRequest\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\xa3\x01\n\x17UpdateCronReportRequest\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateCronReportResponse\"7\n\x14GetCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x15GetCronReportResponse\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteCronReportResponse\"9\n\x16PauseCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x19\n\x17PauseCronReportResponse\":\n\x17ResumeCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18ResumeCronReportResponse\"p\n\x14RunCronReportRequest\x12X\n\ncronreport\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x17\n\x15RunCronReportResponse2\xc4\x0e\n\x11\x43ronReportService\x12\xd3\x01\n\x0fListCronReports\x12L.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest\x1aM.github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/cronreports/{namespace}\x12\xcd\x01\n\x10\x43reateCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/cronreports:\x01*\x12\xd4\x01\n\rGetCronReport\x12J.github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest\x1aK.github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/cronreports/{namespace}/{name}\x12\x88\x02\n\x10UpdateCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/cronreports/{namespace}/{name}\x12\xfc\x01\n\tRunReport\x12J.github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest\x1aK.github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse\"V\x82\xd3\xe4\x93\x02P\"N/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:run\x12\xe0\x01\n\x0fPauseCronReport\x12L.github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest\x1aM.github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/cronreports/{namespace}/{name}:pause\x12\xe4\x01\n\x10ResumeCronReport\x12M.github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest\x1aN.github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse\"1\x82\xd3\xe4\x93\x02+\")/v1/cronreports/{namespace}/{name}:resumeB6Z4github.com/metaprov/modelaapi/services/cronreport/v1b\x06proto3')



_LISTCRONREPORTSREQUEST = DESCRIPTOR.message_types_by_name['ListCronReportsRequest']
_LISTCRONREPORTSREQUEST_LABELSENTRY = _LISTCRONREPORTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCRONREPORTSRESPONSE = DESCRIPTOR.message_types_by_name['ListCronReportsResponse']
_CREATECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['CreateCronReportResponse']
_CREATECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['CreateCronReportRequest']
_UPDATECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['UpdateCronReportRequest']
_UPDATECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCronReportResponse']
_GETCRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['GetCronReportRequest']
_GETCRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['GetCronReportResponse']
_DELETECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['DeleteCronReportRequest']
_DELETECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCronReportResponse']
_PAUSECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['PauseCronReportRequest']
_PAUSECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['PauseCronReportResponse']
_RESUMECRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['ResumeCronReportRequest']
_RESUMECRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['ResumeCronReportResponse']
_RUNCRONREPORTREQUEST = DESCRIPTOR.message_types_by_name['RunCronReportRequest']
_RUNCRONREPORTRESPONSE = DESCRIPTOR.message_types_by_name['RunCronReportResponse']
ListCronReportsRequest = _reflection.GeneratedProtocolMessageType('ListCronReportsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCRONREPORTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCRONREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsRequest)
  })
_sym_db.RegisterMessage(ListCronReportsRequest)
_sym_db.RegisterMessage(ListCronReportsRequest.LabelsEntry)

ListCronReportsResponse = _reflection.GeneratedProtocolMessageType('ListCronReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ListCronReportsResponse)
  })
_sym_db.RegisterMessage(ListCronReportsResponse)

CreateCronReportResponse = _reflection.GeneratedProtocolMessageType('CreateCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportResponse)
  })
_sym_db.RegisterMessage(CreateCronReportResponse)

CreateCronReportRequest = _reflection.GeneratedProtocolMessageType('CreateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.CreateCronReportRequest)
  })
_sym_db.RegisterMessage(CreateCronReportRequest)

UpdateCronReportRequest = _reflection.GeneratedProtocolMessageType('UpdateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportRequest)
  })
_sym_db.RegisterMessage(UpdateCronReportRequest)

UpdateCronReportResponse = _reflection.GeneratedProtocolMessageType('UpdateCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.UpdateCronReportResponse)
  })
_sym_db.RegisterMessage(UpdateCronReportResponse)

GetCronReportRequest = _reflection.GeneratedProtocolMessageType('GetCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportRequest)
  })
_sym_db.RegisterMessage(GetCronReportRequest)

GetCronReportResponse = _reflection.GeneratedProtocolMessageType('GetCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.GetCronReportResponse)
  })
_sym_db.RegisterMessage(GetCronReportResponse)

DeleteCronReportRequest = _reflection.GeneratedProtocolMessageType('DeleteCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportRequest)
  })
_sym_db.RegisterMessage(DeleteCronReportRequest)

DeleteCronReportResponse = _reflection.GeneratedProtocolMessageType('DeleteCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.DeleteCronReportResponse)
  })
_sym_db.RegisterMessage(DeleteCronReportResponse)

PauseCronReportRequest = _reflection.GeneratedProtocolMessageType('PauseCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportRequest)
  })
_sym_db.RegisterMessage(PauseCronReportRequest)

PauseCronReportResponse = _reflection.GeneratedProtocolMessageType('PauseCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.PauseCronReportResponse)
  })
_sym_db.RegisterMessage(PauseCronReportResponse)

ResumeCronReportRequest = _reflection.GeneratedProtocolMessageType('ResumeCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportRequest)
  })
_sym_db.RegisterMessage(ResumeCronReportRequest)

ResumeCronReportResponse = _reflection.GeneratedProtocolMessageType('ResumeCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMECRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.ResumeCronReportResponse)
  })
_sym_db.RegisterMessage(ResumeCronReportResponse)

RunCronReportRequest = _reflection.GeneratedProtocolMessageType('RunCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportRequest)
  })
_sym_db.RegisterMessage(RunCronReportRequest)

RunCronReportResponse = _reflection.GeneratedProtocolMessageType('RunCronReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNCRONREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.cronreport.v1.cronreport_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.cronreport.v1.RunCronReportResponse)
  })
_sym_db.RegisterMessage(RunCronReportResponse)

_CRONREPORTSERVICE = DESCRIPTOR.services_by_name['CronReportService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/cronreport/v1'
  _LISTCRONREPORTSREQUEST_LABELSENTRY._options = None
  _LISTCRONREPORTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CRONREPORTSERVICE.methods_by_name['ListCronReports']._options = None
  _CRONREPORTSERVICE.methods_by_name['ListCronReports']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/cronreports/{namespace}'
  _CRONREPORTSERVICE.methods_by_name['CreateCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['CreateCronReport']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/cronreports:\001*'
  _CRONREPORTSERVICE.methods_by_name['GetCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['GetCronReport']._serialized_options = b'\202\323\344\223\002$\022\"/v1/cronreports/{namespace}/{name}'
  _CRONREPORTSERVICE.methods_by_name['UpdateCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['UpdateCronReport']._serialized_options = b'\202\323\344\223\002O\032J/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:\001*'
  _CRONREPORTSERVICE.methods_by_name['DeleteCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['DeleteCronReport']._serialized_options = b'\202\323\344\223\002$*\"/v1/cronreports/{namespace}/{name}'
  _CRONREPORTSERVICE.methods_by_name['RunReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['RunReport']._serialized_options = b'\202\323\344\223\002P\"N/v1/cronreports/{cronreport.metadata.namespace}/{cronreport.metadata.name}:run'
  _CRONREPORTSERVICE.methods_by_name['PauseCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['PauseCronReport']._serialized_options = b'\202\323\344\223\002*\"(/v1/cronreports/{namespace}/{name}:pause'
  _CRONREPORTSERVICE.methods_by_name['ResumeCronReport']._options = None
  _CRONREPORTSERVICE.methods_by_name['ResumeCronReport']._serialized_options = b'\202\323\344\223\002+\")/v1/cronreports/{namespace}/{name}:resume'
  _LISTCRONREPORTSREQUEST._serialized_start=266
  _LISTCRONREPORTSREQUEST._serialized_end=519
  _LISTCRONREPORTSREQUEST_LABELSENTRY._serialized_start=474
  _LISTCRONREPORTSREQUEST_LABELSENTRY._serialized_end=519
  _LISTCRONREPORTSRESPONSE._serialized_start=522
  _LISTCRONREPORTSRESPONSE._serialized_end=667
  _CREATECRONREPORTRESPONSE._serialized_start=669
  _CREATECRONREPORTRESPONSE._serialized_end=695
  _CREATECRONREPORTREQUEST._serialized_start=697
  _CREATECRONREPORTREQUEST._serialized_end=812
  _UPDATECRONREPORTREQUEST._serialized_start=815
  _UPDATECRONREPORTREQUEST._serialized_end=978
  _UPDATECRONREPORTRESPONSE._serialized_start=980
  _UPDATECRONREPORTRESPONSE._serialized_end=1006
  _GETCRONREPORTREQUEST._serialized_start=1008
  _GETCRONREPORTREQUEST._serialized_end=1063
  _GETCRONREPORTRESPONSE._serialized_start=1065
  _GETCRONREPORTRESPONSE._serialized_end=1192
  _DELETECRONREPORTREQUEST._serialized_start=1194
  _DELETECRONREPORTREQUEST._serialized_end=1252
  _DELETECRONREPORTRESPONSE._serialized_start=1254
  _DELETECRONREPORTRESPONSE._serialized_end=1280
  _PAUSECRONREPORTREQUEST._serialized_start=1282
  _PAUSECRONREPORTREQUEST._serialized_end=1339
  _PAUSECRONREPORTRESPONSE._serialized_start=1341
  _PAUSECRONREPORTRESPONSE._serialized_end=1366
  _RESUMECRONREPORTREQUEST._serialized_start=1368
  _RESUMECRONREPORTREQUEST._serialized_end=1426
  _RESUMECRONREPORTRESPONSE._serialized_start=1428
  _RESUMECRONREPORTRESPONSE._serialized_end=1454
  _RUNCRONREPORTREQUEST._serialized_start=1456
  _RUNCRONREPORTREQUEST._serialized_end=1568
  _RUNCRONREPORTRESPONSE._serialized_start=1570
  _RUNCRONREPORTRESPONSE._serialized_end=1593
  _CRONREPORTSERVICE._serialized_start=1596
  _CRONREPORTSERVICE._serialized_end=3456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/curtain/v1/curtain.proto\x12\x31github.com.metaprov.modelaapi.services.curtain.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\"\xf4\x01\n\x13ListCurtainsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x14ListCurtainsResponse\x12X\n\x08\x63urtains\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CurtainList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x17\n\x15\x43reateCurtainResponse\"k\n\x14\x43reateCurtainRequest\x12S\n\x07\x63urtain\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x9b\x01\n\x14UpdateCurtainRequest\x12S\n\x07\x63urtain\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateCurtainResponse\"4\n\x11GetCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"w\n\x12GetCurtainResponse\x12S\n\x07\x63urtain\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"7\n\x14\x44\x65leteCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteCurtainResponse2\x98\x08\n\x0e\x43urtainService\x12\xc1\x01\n\x0cListCurtains\x12\x46.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest\x1aG.github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/curtains/{namespace}\x12\xbb\x01\n\rCreateCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/curtains:\x01*\x12\xc2\x01\n\nGetCurtain\x12\x44.github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest\x1a\x45.github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/curtains/{namespace}/{name}\x12\xf0\x01\n\rUpdateCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/curtains/{curtain.metadata.namespace}/{curtain.metadata.name}:\x01*\x12\xcb\x01\n\rDeleteCurtain\x12G.github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest\x1aH.github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse\"\'\x82\xd3\xe4\x93\x02!*\x1f/v1/curtains/{namespace}/{name}B3Z1github.com/metaprov/modelaapi/services/curtain/v1b\x06proto3')



_LISTCURTAINSREQUEST = DESCRIPTOR.message_types_by_name['ListCurtainsRequest']
_LISTCURTAINSREQUEST_LABELSENTRY = _LISTCURTAINSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCURTAINSRESPONSE = DESCRIPTOR.message_types_by_name['ListCurtainsResponse']
_CREATECURTAINRESPONSE = DESCRIPTOR.message_types_by_name['CreateCurtainResponse']
_CREATECURTAINREQUEST = DESCRIPTOR.message_types_by_name['CreateCurtainRequest']
_UPDATECURTAINREQUEST = DESCRIPTOR.message_types_by_name['UpdateCurtainRequest']
_UPDATECURTAINRESPONSE = DESCRIPTOR.message_types_by_name['UpdateCurtainResponse']
_GETCURTAINREQUEST = DESCRIPTOR.message_types_by_name['GetCurtainRequest']
_GETCURTAINRESPONSE = DESCRIPTOR.message_types_by_name['GetCurtainResponse']
_DELETECURTAINREQUEST = DESCRIPTOR.message_types_by_name['DeleteCurtainRequest']
_DELETECURTAINRESPONSE = DESCRIPTOR.message_types_by_name['DeleteCurtainResponse']
ListCurtainsRequest = _reflection.GeneratedProtocolMessageType('ListCurtainsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCURTAINSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCURTAINSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsRequest)
  })
_sym_db.RegisterMessage(ListCurtainsRequest)
_sym_db.RegisterMessage(ListCurtainsRequest.LabelsEntry)

ListCurtainsResponse = _reflection.GeneratedProtocolMessageType('ListCurtainsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.ListCurtainsResponse)
  })
_sym_db.RegisterMessage(ListCurtainsResponse)

CreateCurtainResponse = _reflection.GeneratedProtocolMessageType('CreateCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainResponse)
  })
_sym_db.RegisterMessage(CreateCurtainResponse)

CreateCurtainRequest = _reflection.GeneratedProtocolMessageType('CreateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.CreateCurtainRequest)
  })
_sym_db.RegisterMessage(CreateCurtainRequest)

UpdateCurtainRequest = _reflection.GeneratedProtocolMessageType('UpdateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainRequest)
  })
_sym_db.RegisterMessage(UpdateCurtainRequest)

UpdateCurtainResponse = _reflection.GeneratedProtocolMessageType('UpdateCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.UpdateCurtainResponse)
  })
_sym_db.RegisterMessage(UpdateCurtainResponse)

GetCurtainRequest = _reflection.GeneratedProtocolMessageType('GetCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainRequest)
  })
_sym_db.RegisterMessage(GetCurtainRequest)

GetCurtainResponse = _reflection.GeneratedProtocolMessageType('GetCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.GetCurtainResponse)
  })
_sym_db.RegisterMessage(GetCurtainResponse)

DeleteCurtainRequest = _reflection.GeneratedProtocolMessageType('DeleteCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainRequest)
  })
_sym_db.RegisterMessage(DeleteCurtainRequest)

DeleteCurtainResponse = _reflection.GeneratedProtocolMessageType('DeleteCurtainResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.curtain.v1.curtain_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.curtain.v1.DeleteCurtainResponse)
  })
_sym_db.RegisterMessage(DeleteCurtainResponse)

_CURTAINSERVICE = DESCRIPTOR.services_by_name['CurtainService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/curtain/v1'
  _LISTCURTAINSREQUEST_LABELSENTRY._options = None
  _LISTCURTAINSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CURTAINSERVICE.methods_by_name['ListCurtains']._options = None
  _CURTAINSERVICE.methods_by_name['ListCurtains']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/curtains/{namespace}'
  _CURTAINSERVICE.methods_by_name['CreateCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['CreateCurtain']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/curtains:\001*'
  _CURTAINSERVICE.methods_by_name['GetCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['GetCurtain']._serialized_options = b'\202\323\344\223\002!\022\037/v1/curtains/{namespace}/{name}'
  _CURTAINSERVICE.methods_by_name['UpdateCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['UpdateCurtain']._serialized_options = b'\202\323\344\223\002F\032A/v1/curtains/{curtain.metadata.namespace}/{curtain.metadata.name}:\001*'
  _CURTAINSERVICE.methods_by_name['DeleteCurtain']._options = None
  _CURTAINSERVICE.methods_by_name['DeleteCurtain']._serialized_options = b'\202\323\344\223\002!*\037/v1/curtains/{namespace}/{name}'
  _LISTCURTAINSREQUEST._serialized_start=258
  _LISTCURTAINSREQUEST._serialized_end=502
  _LISTCURTAINSREQUEST_LABELSENTRY._serialized_start=457
  _LISTCURTAINSREQUEST_LABELSENTRY._serialized_end=502
  _LISTCURTAINSRESPONSE._serialized_start=505
  _LISTCURTAINSRESPONSE._serialized_end=642
  _CREATECURTAINRESPONSE._serialized_start=644
  _CREATECURTAINRESPONSE._serialized_end=667
  _CREATECURTAINREQUEST._serialized_start=669
  _CREATECURTAINREQUEST._serialized_end=776
  _UPDATECURTAINREQUEST._serialized_start=779
  _UPDATECURTAINREQUEST._serialized_end=934
  _UPDATECURTAINRESPONSE._serialized_start=936
  _UPDATECURTAINRESPONSE._serialized_end=959
  _GETCURTAINREQUEST._serialized_start=961
  _GETCURTAINREQUEST._serialized_end=1013
  _GETCURTAINRESPONSE._serialized_start=1015
  _GETCURTAINRESPONSE._serialized_end=1134
  _DELETECURTAINREQUEST._serialized_start=1136
  _DELETECURTAINREQUEST._serialized_end=1191
  _DELETECURTAINRESPONSE._serialized_start=1193
  _DELETECURTAINRESPONSE._serialized_end=1216
  _CURTAINSERVICE._serialized_start=1219
  _CURTAINSERVICE._serialized_end=2267
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.objectstored.v1 import objectstored_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2


class ObjectstoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ingest = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/Ingest',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.FromString,
                )
        self.Archive = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/Archive',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.FromString,
                )
        self.Recover = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/Recover',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.FromString,
                )
        self.ExistInVirtualBucket = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/ExistInVirtualBucket',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ExistInVirtualBucketResponse.FromString,
                )


class ObjectstoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Ingest(self, request, context):
        """Ingest a new dataset to the store, the store creates a new layouts and set of keys
        for the new dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Archive(self, request, context):
        """Delete a dataset from the store. Datasets are not deleted but moved to archive mode
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Recover(self, request, context):
        """Recover an item from the archive into the depot
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExistInVirtualBucket(self, request, context):
        """Check if a dataset exist in bucket
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ObjectstoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ingest': grpc.unary_unary_rpc_method_handler(
                    servicer.Ingest,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.SerializeToString,
            ),
            'Archive': grpc.unary_unary_rpc_method_handler(
                    servicer.Archive,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.SerializeToString,
            ),
            'Recover': grpc.unary_unary_rpc_method_handler(
                    servicer.Recover,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.SerializeToString,
            ),
            'ExistInVirtualBucket': grpc.unary_unary_rpc_method_handler(
                    servicer.ExistInVirtualBucket,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ExistInVirtualBucketResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ObjectstoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Ingest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/Ingest',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Archive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/Archive',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Recover(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/Recover',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExistInVirtualBucket(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService/ExistInVirtualBucket',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ObjectRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_objectstored_dot_v1_dot_objectstored__pb2.ExistInVirtualBucketResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.connection.v1 import connection_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2


class ConnectionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListConnections = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/ListConnections',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.ListConnectionsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.ListConnectionsResponse.FromString,
                )
        self.CreateConnection = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/CreateConnection',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.CreateConnectionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.CreateConnectionResponse.FromString,
                )
        self.GetConnection = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/GetConnection',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.GetConnectionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.GetConnectionResponse.FromString,
                )
        self.UpdateConnection = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/UpdateConnection',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.UpdateConnectionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.UpdateConnectionResponse.FromString,
                )
        self.DeleteConnection = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/DeleteConnection',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.DeleteConnectionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.DeleteConnectionResponse.FromString,
                )
        self.TestConnection = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/TestConnection',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.TestConnectionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.TestConnectionResponse.FromString,
                )


class ConnectionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListConnections(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListConnections': grpc.unary_unary_rpc_method_handler(
                    servicer.ListConnections,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.ListConnectionsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.ListConnectionsResponse.SerializeToString,
            ),
            'CreateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnection,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.CreateConnectionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.CreateConnectionResponse.SerializeToString,
            ),
            'GetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnection,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.GetConnectionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.GetConnectionResponse.SerializeToString,
            ),
            'UpdateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConnection,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.UpdateConnectionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.UpdateConnectionResponse.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.DeleteConnectionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.DeleteConnectionResponse.SerializeToString,
            ),
            'TestConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.TestConnection,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.TestConnectionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.TestConnectionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.connection.v1.ConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConnectionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListConnections(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/ListConnections',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.ListConnectionsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.ListConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/CreateConnection',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.CreateConnectionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.CreateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/GetConnection',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.GetConnectionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.GetConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/UpdateConnection',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.UpdateConnectionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.UpdateConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/DeleteConnection',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.DeleteConnectionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.DeleteConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.connection.v1.ConnectionService/TestConnection',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.TestConnectionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_connection_dot_v1_dot_connection__pb2.TestConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.prediction.v1 import prediction_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2


class PredictionServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListPredictions = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/ListPredictions',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.ListPredictionsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.ListPredictionsResponse.FromString,
                )
        self.CreatePrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/CreatePrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.CreatePredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.CreatePredictionResponse.FromString,
                )
        self.GetPrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/GetPrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.GetPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.GetPredictionResponse.FromString,
                )
        self.UpdatePrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/UpdatePrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.UpdatePredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.UpdatePredictionResponse.FromString,
                )
        self.DeletePrediction = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/DeletePrediction',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DeletePredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DeletePredictionResponse.FromString,
                )
        self.Download = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/Download',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DownloadPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DownloadPredictionResponse.FromString,
                )
        self.Abort = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/Abort',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.AbortPredictionRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.AbortPredictionResponse.FromString,
                )


class PredictionServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListPredictions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreatePrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdatePrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePrediction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Download(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Abort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PredictionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListPredictions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPredictions,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.ListPredictionsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.ListPredictionsResponse.SerializeToString,
            ),
            'CreatePrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.CreatePrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.CreatePredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.CreatePredictionResponse.SerializeToString,
            ),
            'GetPrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.GetPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.GetPredictionResponse.SerializeToString,
            ),
            'UpdatePrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdatePrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.UpdatePredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.UpdatePredictionResponse.SerializeToString,
            ),
            'DeletePrediction': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePrediction,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DeletePredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DeletePredictionResponse.SerializeToString,
            ),
            'Download': grpc.unary_unary_rpc_method_handler(
                    servicer.Download,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DownloadPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DownloadPredictionResponse.SerializeToString,
            ),
            'Abort': grpc.unary_unary_rpc_method_handler(
                    servicer.Abort,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.AbortPredictionRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.AbortPredictionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.prediction.v1.PredictionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PredictionService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListPredictions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/ListPredictions',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.ListPredictionsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.ListPredictionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreatePrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/CreatePrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.CreatePredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.CreatePredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/GetPrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.GetPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.GetPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdatePrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/UpdatePrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.UpdatePredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.UpdatePredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePrediction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/DeletePrediction',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DeletePredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DeletePredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/Download',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DownloadPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.DownloadPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Abort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.prediction.v1.PredictionService/Abort',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.AbortPredictionRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_prediction_dot_v1_dot_prediction__pb2.AbortPredictionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.meeting.v1 import meeting_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2


class MeetingServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListMeetings = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/ListMeetings',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsResponse.FromString,
                )
        self.CreateMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/CreateMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingResponse.FromString,
                )
        self.GetMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/GetMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingResponse.FromString,
                )
        self.UpdateMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/UpdateMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingResponse.FromString,
                )
        self.DeleteMeeting = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/DeleteMeeting',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingResponse.FromString,
                )


class MeetingServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListMeetings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMeeting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MeetingServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListMeetings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMeetings,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsResponse.SerializeToString,
            ),
            'CreateMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingResponse.SerializeToString,
            ),
            'GetMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingResponse.SerializeToString,
            ),
            'UpdateMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingResponse.SerializeToString,
            ),
            'DeleteMeeting': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMeeting,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.meeting.v1.MeetingService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MeetingService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListMeetings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/ListMeetings',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.ListMeetingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/CreateMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.CreateMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/GetMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.GetMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/UpdateMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.UpdateMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMeeting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.meeting.v1.MeetingService/DeleteMeeting',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_meeting_dot_v1_dot_meeting__pb2.DeleteMeetingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.recipe.v1 import recipe_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2


class RecipeServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListRecipes = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ListRecipes',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesResponse.FromString,
                )
        self.CreateRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/CreateRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeResponse.FromString,
                )
        self.GetRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/GetRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeResponse.FromString,
                )
        self.RunRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/RunRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeResponse.FromString,
                )
        self.ProfileRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ProfileRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeResponse.FromString,
                )
        self.UpdateRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/UpdateRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeResponse.FromString,
                )
        self.DeleteRecipe = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/DeleteRecipe',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeResponse.FromString,
                )


class RecipeServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListRecipes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ProfileRecipe(self, request, context):
        """profile the recipe based on the sample
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecipe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RecipeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListRecipes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRecipes,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesResponse.SerializeToString,
            ),
            'CreateRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeResponse.SerializeToString,
            ),
            'GetRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeResponse.SerializeToString,
            ),
            'RunRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.RunRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeResponse.SerializeToString,
            ),
            'ProfileRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.ProfileRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeResponse.SerializeToString,
            ),
            'UpdateRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeResponse.SerializeToString,
            ),
            'DeleteRecipe': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecipe,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.recipe.v1.RecipeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RecipeService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListRecipes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ListRecipes',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ListRecipesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/CreateRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.CreateRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/GetRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.GetRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/RunRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.RunRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ProfileRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/ProfileRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.ProfileRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/UpdateRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.UpdateRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRecipe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.recipe.v1.RecipeService/DeleteRecipe',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_recipe_dot_v1_dot_recipe__pb2.DeleteRecipeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
